Module: Zarby
- Defined in:
- lib/zarby.rb,
lib/zarby/csv.rb,
lib/zarby/errors.rb,
lib/zarby/version.rb,
lib/zarby/anonymize.rb,
lib/zarby/functions.rb,
lib/zarby/normalize.rb,
sig/zarby.rbs
Defined Under Namespace
Modules: Functions Classes: ArgumentZarby, ColSeparatorZarby, Csv, Foo, Normalize
Constant Summary collapse
- VERSION =
"0.2.2"
Class Method Summary collapse
-
.anonymize(input, nb_chars: 2, mask_with: "*") ⇒ String
Anonymizes a given input by masking the first
nb_charscharacters withmask_with. -
.detect_separator(content) ⇒ String
Detects and returns the separator used in the provided CSV content.
- .plop ⇒ Object
-
.utf8(input) ⇒ String
Normalizes the input string to UTF-8 encoding.
Class Method Details
.anonymize(input, nb_chars: 2, mask_with: "*") ⇒ String
Anonymizes a given input by masking the first nb_chars characters with mask_with.
28 29 30 |
# File 'lib/zarby.rb', line 28 def anonymize(input, nb_chars: 2, mask_with: "*") Anonymize.new(input:, nb_chars:, mask_with:).call end |
.detect_separator(content) ⇒ String
Detects and returns the separator used in the provided CSV content.
36 37 38 |
# File 'lib/zarby.rb', line 36 def detect_separator(content) Csv.new(content:).call end |
.plop ⇒ Object
9 10 11 12 13 14 |
# File 'lib/zarby.rb', line 9 def plop zp "coucou ca va?" puts inspect puts self.class.inspect puts self.class.name end |